/****************************************************************************
** Meta object code from reading C++ file 'UIMainEventListener.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../src/VBox/Frontends/VirtualBox/src/globals/UIMainEventListener.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'UIMainEventListener.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.10.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19UIMainEventListenerE_t {};
} // unnamed namespace

template <> constexpr inline auto UIMainEventListener::qt_create_metaobjectdata<qt_meta_tag_ZN19UIMainEventListenerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UIMainEventListener",
        "sigListeningFinished",
        "",
        "sigVBoxSVCAvailabilityChange",
        "fAvailable",
        "sigMachineStateChange",
        "QUuid",
        "uId",
        "KMachineState",
        "state",
        "sigMachineDataChange",
        "sigMachineRegistered",
        "fRegistered",
        "sigMachineGroupsChange",
        "sigSessionStateChange",
        "KSessionState",
        "sigSnapshotTake",
        "uSnapshotId",
        "sigSnapshotDelete",
        "sigSnapshotChange",
        "sigSnapshotRestore",
        "sigCloudProviderUninstall",
        "sigCloudProviderListChanged",
        "sigCloudProfileRegistered",
        "uProviderId",
        "strName",
        "sigCloudProfileChanged",
        "sigExtensionPackInstalled",
        "sigExtensionPackUninstalled",
        "sigExtraDataCanChange",
        "strKey",
        "strValue",
        "bool&",
        "fVeto",
        "QString&",
        "strVetoReason",
        "sigExtraDataChange",
        "sigStorageControllerChange",
        "uMachineId",
        "strControllerName",
        "sigStorageDeviceChange",
        "CMediumAttachment",
        "comAttachment",
        "fRemoved",
        "fSilent",
        "sigMediumChange",
        "sigMediumConfigChange",
        "CMedium",
        "comMedium",
        "sigMediumRegistered",
        "uMediumId",
        "KDeviceType",
        "enmMediumType",
        "sigMousePointerShapeChange",
        "UIMousePointerShapeData",
        "shapeData",
        "sigMouseCapabilityChange",
        "fSupportsAbsolute",
        "fSupportsRelative",
        "fSupportsTouchScreen",
        "fSupportsTouchPad",
        "fNeedsHostCursor",
        "sigCursorPositionChange",
        "fContainsData",
        "uX",
        "uY",
        "sigKeyboardLedsChange",
        "fNumLock",
        "fCapsLock",
        "fScrollLock",
        "sigStateChange",
        "sigAdditionsChange",
        "sigNetworkAdapterChange",
        "CNetworkAdapter",
        "comAdapter",
        "sigVRDEChange",
        "sigRecordingChange",
        "sigUSBControllerChange",
        "sigUSBDeviceStateChange",
        "CUSBDevice",
        "comDevice",
        "fAttached",
        "CVirtualBoxErrorInfo",
        "comError",
        "sigSharedFolderChange",
        "sigCPUExecutionCapChange",
        "sigGuestMonitorChange",
        "KGuestMonitorChangedEventType",
        "changeType",
        "uScreenId",
        "QRect",
        "screenGeo",
        "sigRuntimeError",
        "fFatal",
        "strErrorId",
        "strMessage",
        "sigCanShowWindow",
        "strReason",
        "sigShowWindow",
        "qint64&",
        "winId",
        "sigAudioAdapterChange",
        "sigClipboardModeChange",
        "KClipboardMode",
        "enmClipboardMode",
        "sigClipboardError",
        "strMsg",
        "sigDnDModeChange",
        "KDnDMode",
        "enmDnDMode",
        "sigProgressPercentageChange",
        "uProgressId",
        "iPercent",
        "sigProgressTaskComplete",
        "sigGuestSessionRegistered",
        "CGuestSession",
        "comGuestSession",
        "sigGuestSessionUnregistered",
        "sigGuestProcessRegistered",
        "CGuestProcess",
        "comGuestProcess",
        "sigGuestProcessUnregistered",
        "sigGuestSessionStatedChanged",
        "CGuestSessionStateChangedEvent",
        "comEvent",
        "sigGuestProcessStateChanged",
        "CGuestProcessStateChangedEvent",
        "sltHandleThreadFinished"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sigListeningFinished'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigVBoxSVCAvailabilityChange'
        QtMocHelpers::SignalData<void(bool)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Signal 'sigMachineStateChange'
        QtMocHelpers::SignalData<void(const QUuid &, const KMachineState)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 8, 9 },
        }}),
        // Signal 'sigMachineDataChange'
        QtMocHelpers::SignalData<void(const QUuid &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'sigMachineRegistered'
        QtMocHelpers::SignalData<void(const QUuid &, const bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { QMetaType::Bool, 12 },
        }}),
        // Signal 'sigMachineGroupsChange'
        QtMocHelpers::SignalData<void(const QUuid &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'sigSessionStateChange'
        QtMocHelpers::SignalData<void(const QUuid &, const KSessionState)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 15, 9 },
        }}),
        // Signal 'sigSnapshotTake'
        QtMocHelpers::SignalData<void(const QUuid &, const QUuid &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 17 },
        }}),
        // Signal 'sigSnapshotDelete'
        QtMocHelpers::SignalData<void(const QUuid &, const QUuid &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 17 },
        }}),
        // Signal 'sigSnapshotChange'
        QtMocHelpers::SignalData<void(const QUuid &, const QUuid &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 17 },
        }}),
        // Signal 'sigSnapshotRestore'
        QtMocHelpers::SignalData<void(const QUuid &, const QUuid &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 17 },
        }}),
        // Signal 'sigCloudProviderUninstall'
        QtMocHelpers::SignalData<void(const QUuid &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'sigCloudProviderListChanged'
        QtMocHelpers::SignalData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigCloudProfileRegistered'
        QtMocHelpers::SignalData<void(const QUuid &, const QString &, bool)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 24 }, { QMetaType::QString, 25 }, { QMetaType::Bool, 12 },
        }}),
        // Signal 'sigCloudProfileChanged'
        QtMocHelpers::SignalData<void(const QUuid &, const QString &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 24 }, { QMetaType::QString, 25 },
        }}),
        // Signal 'sigExtensionPackInstalled'
        QtMocHelpers::SignalData<void(const QString &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
        // Signal 'sigExtensionPackUninstalled'
        QtMocHelpers::SignalData<void(const QString &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
        // Signal 'sigExtraDataCanChange'
        QtMocHelpers::SignalData<void(const QUuid &, const QString &, const QString &, bool &, QString &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { QMetaType::QString, 30 }, { QMetaType::QString, 31 }, { 0x80000000 | 32, 33 },
            { 0x80000000 | 34, 35 },
        }}),
        // Signal 'sigExtraDataChange'
        QtMocHelpers::SignalData<void(const QUuid &, const QString &, const QString &)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { QMetaType::QString, 30 }, { QMetaType::QString, 31 },
        }}),
        // Signal 'sigStorageControllerChange'
        QtMocHelpers::SignalData<void(const QUuid &, const QString &)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 38 }, { QMetaType::QString, 39 },
        }}),
        // Signal 'sigStorageDeviceChange'
        QtMocHelpers::SignalData<void(CMediumAttachment, bool, bool)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 41, 42 }, { QMetaType::Bool, 43 }, { QMetaType::Bool, 44 },
        }}),
        // Signal 'sigMediumChange'
        QtMocHelpers::SignalData<void(CMediumAttachment)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 41, 42 },
        }}),
        // Signal 'sigMediumConfigChange'
        QtMocHelpers::SignalData<void(CMedium)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 47, 48 },
        }}),
        // Signal 'sigMediumRegistered'
        QtMocHelpers::SignalData<void(const QUuid &, KDeviceType, bool)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 50 }, { 0x80000000 | 51, 52 }, { QMetaType::Bool, 12 },
        }}),
        // Signal 'sigMousePointerShapeChange'
        QtMocHelpers::SignalData<void(const UIMousePointerShapeData &)>(53, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 54, 55 },
        }}),
        // Signal 'sigMouseCapabilityChange'
        QtMocHelpers::SignalData<void(bool, bool, bool, bool, bool)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 57 }, { QMetaType::Bool, 58 }, { QMetaType::Bool, 59 }, { QMetaType::Bool, 60 },
            { QMetaType::Bool, 61 },
        }}),
        // Signal 'sigCursorPositionChange'
        QtMocHelpers::SignalData<void(bool, unsigned long, unsigned long)>(62, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 63 }, { QMetaType::ULong, 64 }, { QMetaType::ULong, 65 },
        }}),
        // Signal 'sigKeyboardLedsChange'
        QtMocHelpers::SignalData<void(bool, bool, bool)>(66, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 67 }, { QMetaType::Bool, 68 }, { QMetaType::Bool, 69 },
        }}),
        // Signal 'sigStateChange'
        QtMocHelpers::SignalData<void(KMachineState)>(70, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'sigAdditionsChange'
        QtMocHelpers::SignalData<void()>(71, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigNetworkAdapterChange'
        QtMocHelpers::SignalData<void(CNetworkAdapter)>(72, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 73, 74 },
        }}),
        // Signal 'sigVRDEChange'
        QtMocHelpers::SignalData<void()>(75, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigRecordingChange'
        QtMocHelpers::SignalData<void()>(76, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigUSBControllerChange'
        QtMocHelpers::SignalData<void()>(77, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigUSBDeviceStateChange'
        QtMocHelpers::SignalData<void(CUSBDevice, bool, CVirtualBoxErrorInfo)>(78, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 79, 80 }, { QMetaType::Bool, 81 }, { 0x80000000 | 82, 83 },
        }}),
        // Signal 'sigSharedFolderChange'
        QtMocHelpers::SignalData<void()>(84, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigCPUExecutionCapChange'
        QtMocHelpers::SignalData<void()>(85, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigGuestMonitorChange'
        QtMocHelpers::SignalData<void(KGuestMonitorChangedEventType, ulong, QRect)>(86, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 87, 88 }, { QMetaType::ULong, 89 }, { 0x80000000 | 90, 91 },
        }}),
        // Signal 'sigRuntimeError'
        QtMocHelpers::SignalData<void(bool, QString, QString)>(92, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 93 }, { QMetaType::QString, 94 }, { QMetaType::QString, 95 },
        }}),
        // Signal 'sigCanShowWindow'
        QtMocHelpers::SignalData<void(bool &, QString &)>(96, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 33 }, { 0x80000000 | 34, 97 },
        }}),
        // Signal 'sigShowWindow'
        QtMocHelpers::SignalData<void(qint64 &)>(98, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 99, 100 },
        }}),
        // Signal 'sigAudioAdapterChange'
        QtMocHelpers::SignalData<void()>(101, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigClipboardModeChange'
        QtMocHelpers::SignalData<void(KClipboardMode)>(102, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 103, 104 },
        }}),
        // Signal 'sigClipboardError'
        QtMocHelpers::SignalData<void(const QString &)>(105, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 106 },
        }}),
        // Signal 'sigDnDModeChange'
        QtMocHelpers::SignalData<void(KDnDMode)>(107, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 108, 109 },
        }}),
        // Signal 'sigProgressPercentageChange'
        QtMocHelpers::SignalData<void(const QUuid &, const int)>(110, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 111 }, { QMetaType::Int, 112 },
        }}),
        // Signal 'sigProgressTaskComplete'
        QtMocHelpers::SignalData<void(const QUuid &)>(113, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 111 },
        }}),
        // Signal 'sigGuestSessionRegistered'
        QtMocHelpers::SignalData<void(CGuestSession)>(114, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 115, 116 },
        }}),
        // Signal 'sigGuestSessionUnregistered'
        QtMocHelpers::SignalData<void(CGuestSession)>(117, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 115, 116 },
        }}),
        // Signal 'sigGuestProcessRegistered'
        QtMocHelpers::SignalData<void(CGuestProcess)>(118, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 119, 120 },
        }}),
        // Signal 'sigGuestProcessUnregistered'
        QtMocHelpers::SignalData<void(CGuestProcess)>(121, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 119, 120 },
        }}),
        // Signal 'sigGuestSessionStatedChanged'
        QtMocHelpers::SignalData<void(const CGuestSessionStateChangedEvent &)>(122, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 123, 124 },
        }}),
        // Signal 'sigGuestProcessStateChanged'
        QtMocHelpers::SignalData<void(const CGuestProcessStateChangedEvent &)>(125, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 126, 124 },
        }}),
        // Slot 'sltHandleThreadFinished'
        QtMocHelpers::SlotData<void()>(127, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UIMainEventListener, qt_meta_tag_ZN19UIMainEventListenerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UIMainEventListener::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19UIMainEventListenerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19UIMainEventListenerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19UIMainEventListenerE_t>.metaTypes,
    nullptr
} };

void UIMainEventListener::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UIMainEventListener *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sigListeningFinished(); break;
        case 1: _t->sigVBoxSVCAvailabilityChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->sigMachineStateChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KMachineState>>(_a[2]))); break;
        case 3: _t->sigMachineDataChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1]))); break;
        case 4: _t->sigMachineRegistered((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 5: _t->sigMachineGroupsChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1]))); break;
        case 6: _t->sigSessionStateChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KSessionState>>(_a[2]))); break;
        case 7: _t->sigSnapshotTake((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[2]))); break;
        case 8: _t->sigSnapshotDelete((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[2]))); break;
        case 9: _t->sigSnapshotChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[2]))); break;
        case 10: _t->sigSnapshotRestore((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[2]))); break;
        case 11: _t->sigCloudProviderUninstall((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1]))); break;
        case 12: _t->sigCloudProviderListChanged(); break;
        case 13: _t->sigCloudProfileRegistered((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 14: _t->sigCloudProfileChanged((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 15: _t->sigExtensionPackInstalled((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->sigExtensionPackUninstalled((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->sigExtraDataCanChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[5]))); break;
        case 18: _t->sigExtraDataChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 19: _t->sigStorageControllerChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 20: _t->sigStorageDeviceChange((*reinterpret_cast<std::add_pointer_t<CMediumAttachment>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 21: _t->sigMediumChange((*reinterpret_cast<std::add_pointer_t<CMediumAttachment>>(_a[1]))); break;
        case 22: _t->sigMediumConfigChange((*reinterpret_cast<std::add_pointer_t<CMedium>>(_a[1]))); break;
        case 23: _t->sigMediumRegistered((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KDeviceType>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 24: _t->sigMousePointerShapeChange((*reinterpret_cast<std::add_pointer_t<UIMousePointerShapeData>>(_a[1]))); break;
        case 25: _t->sigMouseCapabilityChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        case 26: _t->sigCursorPositionChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ulong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<ulong>>(_a[3]))); break;
        case 27: _t->sigKeyboardLedsChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 28: _t->sigStateChange((*reinterpret_cast<std::add_pointer_t<KMachineState>>(_a[1]))); break;
        case 29: _t->sigAdditionsChange(); break;
        case 30: _t->sigNetworkAdapterChange((*reinterpret_cast<std::add_pointer_t<CNetworkAdapter>>(_a[1]))); break;
        case 31: _t->sigVRDEChange(); break;
        case 32: _t->sigRecordingChange(); break;
        case 33: _t->sigUSBControllerChange(); break;
        case 34: _t->sigUSBDeviceStateChange((*reinterpret_cast<std::add_pointer_t<CUSBDevice>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<CVirtualBoxErrorInfo>>(_a[3]))); break;
        case 35: _t->sigSharedFolderChange(); break;
        case 36: _t->sigCPUExecutionCapChange(); break;
        case 37: _t->sigGuestMonitorChange((*reinterpret_cast<std::add_pointer_t<KGuestMonitorChangedEventType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ulong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QRect>>(_a[3]))); break;
        case 38: _t->sigRuntimeError((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 39: _t->sigCanShowWindow((*reinterpret_cast<std::add_pointer_t<bool&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[2]))); break;
        case 40: _t->sigShowWindow((*reinterpret_cast<std::add_pointer_t<qint64&>>(_a[1]))); break;
        case 41: _t->sigAudioAdapterChange(); break;
        case 42: _t->sigClipboardModeChange((*reinterpret_cast<std::add_pointer_t<KClipboardMode>>(_a[1]))); break;
        case 43: _t->sigClipboardError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 44: _t->sigDnDModeChange((*reinterpret_cast<std::add_pointer_t<KDnDMode>>(_a[1]))); break;
        case 45: _t->sigProgressPercentageChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 46: _t->sigProgressTaskComplete((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1]))); break;
        case 47: _t->sigGuestSessionRegistered((*reinterpret_cast<std::add_pointer_t<CGuestSession>>(_a[1]))); break;
        case 48: _t->sigGuestSessionUnregistered((*reinterpret_cast<std::add_pointer_t<CGuestSession>>(_a[1]))); break;
        case 49: _t->sigGuestProcessRegistered((*reinterpret_cast<std::add_pointer_t<CGuestProcess>>(_a[1]))); break;
        case 50: _t->sigGuestProcessUnregistered((*reinterpret_cast<std::add_pointer_t<CGuestProcess>>(_a[1]))); break;
        case 51: _t->sigGuestSessionStatedChanged((*reinterpret_cast<std::add_pointer_t<CGuestSessionStateChangedEvent>>(_a[1]))); break;
        case 52: _t->sigGuestProcessStateChanged((*reinterpret_cast<std::add_pointer_t<CGuestProcessStateChangedEvent>>(_a[1]))); break;
        case 53: _t->sltHandleThreadFinished(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KMachineState >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KSessionState >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< CMediumAttachment >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< CMediumAttachment >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< CMedium >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KDeviceType >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KMachineState >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< CNetworkAdapter >(); break;
            }
            break;
        case 34:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< CUSBDevice >(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< CVirtualBoxErrorInfo >(); break;
            }
            break;
        case 37:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KGuestMonitorChangedEventType >(); break;
            }
            break;
        case 42:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KClipboardMode >(); break;
            }
            break;
        case 44:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KDnDMode >(); break;
            }
            break;
        case 47:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< CGuestSession >(); break;
            }
            break;
        case 48:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< CGuestSession >(); break;
            }
            break;
        case 49:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< CGuestProcess >(); break;
            }
            break;
        case 50:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< CGuestProcess >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)()>(_a, &UIMainEventListener::sigListeningFinished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(bool )>(_a, &UIMainEventListener::sigVBoxSVCAvailabilityChange, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(const QUuid & , const KMachineState )>(_a, &UIMainEventListener::sigMachineStateChange, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(const QUuid & )>(_a, &UIMainEventListener::sigMachineDataChange, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(const QUuid & , const bool )>(_a, &UIMainEventListener::sigMachineRegistered, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(const QUuid & )>(_a, &UIMainEventListener::sigMachineGroupsChange, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(const QUuid & , const KSessionState )>(_a, &UIMainEventListener::sigSessionStateChange, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(const QUuid & , const QUuid & )>(_a, &UIMainEventListener::sigSnapshotTake, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(const QUuid & , const QUuid & )>(_a, &UIMainEventListener::sigSnapshotDelete, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(const QUuid & , const QUuid & )>(_a, &UIMainEventListener::sigSnapshotChange, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(const QUuid & , const QUuid & )>(_a, &UIMainEventListener::sigSnapshotRestore, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(const QUuid & )>(_a, &UIMainEventListener::sigCloudProviderUninstall, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)()>(_a, &UIMainEventListener::sigCloudProviderListChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(const QUuid & , const QString & , bool )>(_a, &UIMainEventListener::sigCloudProfileRegistered, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(const QUuid & , const QString & )>(_a, &UIMainEventListener::sigCloudProfileChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(const QString & )>(_a, &UIMainEventListener::sigExtensionPackInstalled, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(const QString & )>(_a, &UIMainEventListener::sigExtensionPackUninstalled, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(const QUuid & , const QString & , const QString & , bool & , QString & )>(_a, &UIMainEventListener::sigExtraDataCanChange, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(const QUuid & , const QString & , const QString & )>(_a, &UIMainEventListener::sigExtraDataChange, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(const QUuid & , const QString & )>(_a, &UIMainEventListener::sigStorageControllerChange, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(CMediumAttachment , bool , bool )>(_a, &UIMainEventListener::sigStorageDeviceChange, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(CMediumAttachment )>(_a, &UIMainEventListener::sigMediumChange, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(CMedium )>(_a, &UIMainEventListener::sigMediumConfigChange, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(const QUuid & , KDeviceType , bool )>(_a, &UIMainEventListener::sigMediumRegistered, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(const UIMousePointerShapeData & )>(_a, &UIMainEventListener::sigMousePointerShapeChange, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(bool , bool , bool , bool , bool )>(_a, &UIMainEventListener::sigMouseCapabilityChange, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(bool , unsigned long , unsigned long )>(_a, &UIMainEventListener::sigCursorPositionChange, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(bool , bool , bool )>(_a, &UIMainEventListener::sigKeyboardLedsChange, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(KMachineState )>(_a, &UIMainEventListener::sigStateChange, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)()>(_a, &UIMainEventListener::sigAdditionsChange, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(CNetworkAdapter )>(_a, &UIMainEventListener::sigNetworkAdapterChange, 30))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)()>(_a, &UIMainEventListener::sigVRDEChange, 31))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)()>(_a, &UIMainEventListener::sigRecordingChange, 32))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)()>(_a, &UIMainEventListener::sigUSBControllerChange, 33))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(CUSBDevice , bool , CVirtualBoxErrorInfo )>(_a, &UIMainEventListener::sigUSBDeviceStateChange, 34))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)()>(_a, &UIMainEventListener::sigSharedFolderChange, 35))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)()>(_a, &UIMainEventListener::sigCPUExecutionCapChange, 36))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(KGuestMonitorChangedEventType , ulong , QRect )>(_a, &UIMainEventListener::sigGuestMonitorChange, 37))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(bool , QString , QString )>(_a, &UIMainEventListener::sigRuntimeError, 38))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(bool & , QString & )>(_a, &UIMainEventListener::sigCanShowWindow, 39))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(qint64 & )>(_a, &UIMainEventListener::sigShowWindow, 40))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)()>(_a, &UIMainEventListener::sigAudioAdapterChange, 41))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(KClipboardMode )>(_a, &UIMainEventListener::sigClipboardModeChange, 42))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(const QString & )>(_a, &UIMainEventListener::sigClipboardError, 43))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(KDnDMode )>(_a, &UIMainEventListener::sigDnDModeChange, 44))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(const QUuid & , const int )>(_a, &UIMainEventListener::sigProgressPercentageChange, 45))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(const QUuid & )>(_a, &UIMainEventListener::sigProgressTaskComplete, 46))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(CGuestSession )>(_a, &UIMainEventListener::sigGuestSessionRegistered, 47))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(CGuestSession )>(_a, &UIMainEventListener::sigGuestSessionUnregistered, 48))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(CGuestProcess )>(_a, &UIMainEventListener::sigGuestProcessRegistered, 49))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(CGuestProcess )>(_a, &UIMainEventListener::sigGuestProcessUnregistered, 50))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(const CGuestSessionStateChangedEvent & )>(_a, &UIMainEventListener::sigGuestSessionStatedChanged, 51))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMainEventListener::*)(const CGuestProcessStateChangedEvent & )>(_a, &UIMainEventListener::sigGuestProcessStateChanged, 52))
            return;
    }
}

const QMetaObject *UIMainEventListener::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UIMainEventListener::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19UIMainEventListenerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int UIMainEventListener::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 54)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 54;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 54)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 54;
    }
    return _id;
}

// SIGNAL 0
void UIMainEventListener::sigListeningFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void UIMainEventListener::sigVBoxSVCAvailabilityChange(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void UIMainEventListener::sigMachineStateChange(const QUuid & _t1, const KMachineState _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void UIMainEventListener::sigMachineDataChange(const QUuid & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void UIMainEventListener::sigMachineRegistered(const QUuid & _t1, const bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void UIMainEventListener::sigMachineGroupsChange(const QUuid & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void UIMainEventListener::sigSessionStateChange(const QUuid & _t1, const KSessionState _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void UIMainEventListener::sigSnapshotTake(const QUuid & _t1, const QUuid & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void UIMainEventListener::sigSnapshotDelete(const QUuid & _t1, const QUuid & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void UIMainEventListener::sigSnapshotChange(const QUuid & _t1, const QUuid & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2);
}

// SIGNAL 10
void UIMainEventListener::sigSnapshotRestore(const QUuid & _t1, const QUuid & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2);
}

// SIGNAL 11
void UIMainEventListener::sigCloudProviderUninstall(const QUuid & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void UIMainEventListener::sigCloudProviderListChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void UIMainEventListener::sigCloudProfileRegistered(const QUuid & _t1, const QString & _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1, _t2, _t3);
}

// SIGNAL 14
void UIMainEventListener::sigCloudProfileChanged(const QUuid & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1, _t2);
}

// SIGNAL 15
void UIMainEventListener::sigExtensionPackInstalled(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void UIMainEventListener::sigExtensionPackUninstalled(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void UIMainEventListener::sigExtraDataCanChange(const QUuid & _t1, const QString & _t2, const QString & _t3, bool & _t4, QString & _t5)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1, _t2, _t3, _t4, _t5);
}

// SIGNAL 18
void UIMainEventListener::sigExtraDataChange(const QUuid & _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1, _t2, _t3);
}

// SIGNAL 19
void UIMainEventListener::sigStorageControllerChange(const QUuid & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1, _t2);
}

// SIGNAL 20
void UIMainEventListener::sigStorageDeviceChange(CMediumAttachment _t1, bool _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1, _t2, _t3);
}

// SIGNAL 21
void UIMainEventListener::sigMediumChange(CMediumAttachment _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1);
}

// SIGNAL 22
void UIMainEventListener::sigMediumConfigChange(CMedium _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1);
}

// SIGNAL 23
void UIMainEventListener::sigMediumRegistered(const QUuid & _t1, KDeviceType _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 23, nullptr, _t1, _t2, _t3);
}

// SIGNAL 24
void UIMainEventListener::sigMousePointerShapeChange(const UIMousePointerShapeData & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 24, nullptr, _t1);
}

// SIGNAL 25
void UIMainEventListener::sigMouseCapabilityChange(bool _t1, bool _t2, bool _t3, bool _t4, bool _t5)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 25, nullptr, _t1, _t2, _t3, _t4, _t5);
}

// SIGNAL 26
void UIMainEventListener::sigCursorPositionChange(bool _t1, unsigned long _t2, unsigned long _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 26, nullptr, _t1, _t2, _t3);
}

// SIGNAL 27
void UIMainEventListener::sigKeyboardLedsChange(bool _t1, bool _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 27, nullptr, _t1, _t2, _t3);
}

// SIGNAL 28
void UIMainEventListener::sigStateChange(KMachineState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 28, nullptr, _t1);
}

// SIGNAL 29
void UIMainEventListener::sigAdditionsChange()
{
    QMetaObject::activate(this, &staticMetaObject, 29, nullptr);
}

// SIGNAL 30
void UIMainEventListener::sigNetworkAdapterChange(CNetworkAdapter _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 30, nullptr, _t1);
}

// SIGNAL 31
void UIMainEventListener::sigVRDEChange()
{
    QMetaObject::activate(this, &staticMetaObject, 31, nullptr);
}

// SIGNAL 32
void UIMainEventListener::sigRecordingChange()
{
    QMetaObject::activate(this, &staticMetaObject, 32, nullptr);
}

// SIGNAL 33
void UIMainEventListener::sigUSBControllerChange()
{
    QMetaObject::activate(this, &staticMetaObject, 33, nullptr);
}

// SIGNAL 34
void UIMainEventListener::sigUSBDeviceStateChange(CUSBDevice _t1, bool _t2, CVirtualBoxErrorInfo _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 34, nullptr, _t1, _t2, _t3);
}

// SIGNAL 35
void UIMainEventListener::sigSharedFolderChange()
{
    QMetaObject::activate(this, &staticMetaObject, 35, nullptr);
}

// SIGNAL 36
void UIMainEventListener::sigCPUExecutionCapChange()
{
    QMetaObject::activate(this, &staticMetaObject, 36, nullptr);
}

// SIGNAL 37
void UIMainEventListener::sigGuestMonitorChange(KGuestMonitorChangedEventType _t1, ulong _t2, QRect _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 37, nullptr, _t1, _t2, _t3);
}

// SIGNAL 38
void UIMainEventListener::sigRuntimeError(bool _t1, QString _t2, QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 38, nullptr, _t1, _t2, _t3);
}

// SIGNAL 39
void UIMainEventListener::sigCanShowWindow(bool & _t1, QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 39, nullptr, _t1, _t2);
}

// SIGNAL 40
void UIMainEventListener::sigShowWindow(qint64 & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 40, nullptr, _t1);
}

// SIGNAL 41
void UIMainEventListener::sigAudioAdapterChange()
{
    QMetaObject::activate(this, &staticMetaObject, 41, nullptr);
}

// SIGNAL 42
void UIMainEventListener::sigClipboardModeChange(KClipboardMode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 42, nullptr, _t1);
}

// SIGNAL 43
void UIMainEventListener::sigClipboardError(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 43, nullptr, _t1);
}

// SIGNAL 44
void UIMainEventListener::sigDnDModeChange(KDnDMode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 44, nullptr, _t1);
}

// SIGNAL 45
void UIMainEventListener::sigProgressPercentageChange(const QUuid & _t1, const int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 45, nullptr, _t1, _t2);
}

// SIGNAL 46
void UIMainEventListener::sigProgressTaskComplete(const QUuid & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 46, nullptr, _t1);
}

// SIGNAL 47
void UIMainEventListener::sigGuestSessionRegistered(CGuestSession _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 47, nullptr, _t1);
}

// SIGNAL 48
void UIMainEventListener::sigGuestSessionUnregistered(CGuestSession _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 48, nullptr, _t1);
}

// SIGNAL 49
void UIMainEventListener::sigGuestProcessRegistered(CGuestProcess _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 49, nullptr, _t1);
}

// SIGNAL 50
void UIMainEventListener::sigGuestProcessUnregistered(CGuestProcess _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 50, nullptr, _t1);
}

// SIGNAL 51
void UIMainEventListener::sigGuestSessionStatedChanged(const CGuestSessionStateChangedEvent & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 51, nullptr, _t1);
}

// SIGNAL 52
void UIMainEventListener::sigGuestProcessStateChanged(const CGuestProcessStateChangedEvent & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 52, nullptr, _t1);
}
QT_WARNING_POP
